@@ -31,7 +31,6 @@
 #include <KLocalizedString>
 #include <KMessageBox>
 #include <KPluginMetaData>
-#include <KServiceTypeTrader>
 #include <KStandardAction>
 #include <KToolBar>
 #include <KWindowConfig>
@@ -126,6 +125,18 @@ void SettingsBase::initApplication()
     // enforce minimum window size
     setMinimumSize(SettingsBase::sizeHint());
     activateWindow();
+
+    // Change size limit after screen resolution is changed
+    m_screen = qGuiApp->primaryScreen();
+    connect(qGuiApp, &QGuiApplication::primaryScreenChanged, this, [this](QScreen *screen) {
+        if (m_screen) {
+            disconnect(m_screen, &QScreen::geometryChanged, this, &SettingsBase::slotGeometryChanged);
+        }
+        m_screen = screen;
+        slotGeometryChanged();
+        connect(m_screen, &QScreen::geometryChanged, this, &SettingsBase::slotGeometryChanged);
+    });
+    connect(m_screen, &QScreen::geometryChanged, this, &SettingsBase::slotGeometryChanged);
 }
 
 void SettingsBase::initToolBar()
@@ -454,3 +465,8 @@ void SettingsBase::changeAboutMenu(const KAboutData *menuAbout, QAction *menuIte
         menuItem->setEnabled(false);
     }
 }
+
+void SettingsBase::slotGeometryChanged()
+{
+    setMinimumSize(SettingsBase::sizeHint());
+}
