@@ -43,6 +43,7 @@ QHash<int, QByteArray> MenuModel::roleNames() const
     names[IsCategoryRole] = "IsCategoryRole";
     names[IsKCMRole] = "IsKCMRole";
     names[DefaultIndicatorRole] = "showDefaultIndicator";
+    names[IconNameRole] = "iconName";
     return names;
 }
 
@@ -76,9 +77,6 @@ QVariant MenuModel::data(const QModelIndex &index, int role) const
     case Qt::DisplayRole:
         theData.setValue(mi->name());
         break;
-    case Qt::ToolTipRole:
-        theData.setValue(mi->comment());
-        break;
     case Qt::DecorationRole:
         theData = QVariant(QIcon::fromTheme(mi->iconName()));
         break;
@@ -145,6 +143,9 @@ QVariant MenuModel::data(const QModelIndex &index, int role) const
     case MenuModel::DefaultIndicatorRole:
         theData.setValue(mi->showDefaultIndicator());
         break;
+    case MenuModel::IconNameRole:
+        theData.setValue(mi->iconName());
+        break;
     default:
         break;
     }
